# Logos and Icons

## Quansight

### logo solid white background

## ![logo transparent background](../images/quansight_logo_white.png)

## Quansight Labs

### Logo solid white background

## ![logo solid background](../images/labs_logo_white.png)

## Qhub Cloud

### transparent background

![logo transparent background](../images/qhub_logo.png)
